@@ -11,19 +11,19 @@
 #include "ksquareswindow.h"
 
 //qt
-#include <QtGui/QStandardItemModel>
-#include <QtCore/QTimer>
+#include <QAction>
+#include <QDebug>
+#include <QLabel>
+#include <QStandardItemModel>
+#include <QStatusBar>
+#include <QTimer>
 
 //kde
 #include <KConfigDialog>
 #include <KActionCollection>
-#include <QDebug>
 #include <KLocalizedString>
 #include <KScoreDialog>
 #include <KStandardGameAction>
-#include <QStatusBar>
-#include <QAction>
-#include <QLabel>
 
 //generated
 #include "settings.h"
@@ -177,7 +177,7 @@ void KSquaresWindow::gameReset()
     //start game etc.
     sGame->createGame(playerList, Settings::boardWidth(), Settings::boardHeight());
     connect(m_scene, &GameBoardScene::lineDrawn, sGame, &KSquaresGame::addLineToIndex);
-    //QT5: VERIFY SIGNAL DOESNT EXIST connect(m_scene,&GameBoardScene::signalMoveRequest,this,&KSquaresWindow::slotMoveRequest);
+    //QT5: VERIFY SIGNAL DOESN'T EXIST connect(m_scene,&GameBoardScene::signalMoveRequest,this,&KSquaresWindow::slotMoveRequest);
     connect(sGame, &KSquaresGame::drawLine, m_scene, &GameBoardScene::drawLine);
     connect(sGame, &KSquaresGame::highlightMove, m_scene, &GameBoardScene::highlightLine);
     connect(sGame, &KSquaresGame::drawSquare, m_scene, &GameBoardScene::drawSquare);
